stalker.db.session — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

#### Previous topic

stalker.db.query

#### Next topic

stalker.db.setup

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

# stalker.db.session

`stalker.db.` `session`

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

© Copyright 2010, Erkan Ozgur Yilmaz. Created using Sphinx 1.0.7.